@@ -18,7 +18,7 @@ MARGIN_TOP: int = 3
 MARGIN_RIGHT: int = 4
 CHAR_PRECISION: int = 6
 DEC_PRECISION: int = 5
-WIDTH: int = CHAR_PRECISION + MARGIN_RIGHT + 1 + DEC_PRECISION + MARGIN_RIGHT
+WIDTH: int = CHAR_PRECISION + 1 + DEC_PRECISION + MARGIN_RIGHT
 HEIGHT: int = 2
 Y_AXIS_SPACING = 4
 
@@ -39,3 +39,6 @@ UNICODE_WICK_LOWER: str = "╵"
 UNICODE_WICK_UPPER: str = "╷"
 MIN_DIFF_THRESHOLD = 0.25
 MAX_DIFF_THRESHOLD = 0.75
+
+# Chart options
+Y_AXIS_ON_THE_RIGHT = False
